package com.objis.demohibernate.test;

import java.util.Date;

import junit.framework.TestCase;

import org.hibernate.Transaction;
import org.hibernate.classic.Session;

import com.objis.demohibernate.domaine.Formation;
import com.objis.demohibernate.domaine.Lieu;
import com.objis.demohibernate.util.HibernateUtil;

public class TestAssociationManyToOne extends TestCase {

	private static Session session = null;
	private static Transaction tx = null;

	protected void setUp() throws Exception {
		super.setUp();
		
		// Ouverture unit de travail hibernate
		session = HibernateUtil.getSessionFactory().openSession();

		// Ouverture transaction
		tx = session.beginTransaction();
	}

	public TestAssociationManyToOne() {
		super();

	}

	public static void testInsertion() {
		System.out.println("\n############### testInsertion ###############");
		
		// Instanciation Objets mtiers
		Lieu lieu = new Lieu("So@t","104, bis rue de Reuilly, 75012 Paris");
		Formation formation = new Formation("Hibernate",new Date(),3,lieu);

		// Persistance Objet/Relationnel : cration d'un enregistrement en base		
		Long lieuId = (Long) session.save(lieu);
		System.out.println("=> Cl primaire Lieu :" + lieuId);
				
		// Persistance Objet/Relationnel : cration d'un enregistrement en base		
		Long formationId = (Long) session.save(formation);
		System.out.println("=> Cl primaire Formation :" + formationId);
	}
	
	public static void testChargementLoad() {		
		System.out.println("\n############### testChargementLoad ###############");
		
		// Rcup Formation (Chargement d'une formation  partir de son Id)
		Formation f = (Formation)session.load(Formation.class, new Long(1));
		
		System.out.println(" >>>>>>>>>>>> Load fait = Select Formation pas encore fait <<<<<<<<<<<< ");
		
		// Rcup proxy Lieu
		Lieu lieu = f.getLieu();
		
		// Chargement effectif du Lieu (Requte SELECT)		
		String lieuNom = lieu.getNom();
		System.out.println("=> nom du lieu :" + lieuNom);
	}
	
	public static void testChargementGet() {		
		System.out.println("\n############### testChargementGet ###############");
		
		// Rcup Formation (Chargement d'une formation  partir de son Id)
		Formation f = (Formation)session.get(Formation.class, new Long(1));
		
		System.out.println(" >>>>>>>>>>>> Get fait = Select Formation dj fait <<<<<<<<<<<< ");
		
		// Rcup proxy Lieu
		Lieu lieu = f.getLieu();
		
		// Chargement effectif du Lieu (Requte SELECT)		
		String lieuNom = lieu.getNom();
		System.out.println("=> nom du lieu :" + lieuNom);
	}

	public static void testDemoProxy() {		
		System.out.println("\n############### testDemoProxy ###############");
		
		// Rcup Proxy Lieu (pas de select ralis, besoin juste de l'Id)
		Lieu lieu = (Lieu)session.load(Lieu.class, new Long(1));
		
		// Cration formation transient et affectation lieu
		Formation f = new Formation("Spring");
		f.setLieu(lieu);
		
		// Sauvegarde de la formation	
		session.save(f);
	}
	
	public static void testSauvegardeCollection() {		
		System.out.println("\n############### testSauvegardeCollection ###############");
		
		// --->>>> Enlever cascade=all dans Formation.hbm.xml pour faire planter <<<<
		
		// Rcup Formation (Chargement d'une formation  partir de son Id)
		Formation f = (Formation)session.load(Formation.class, new Long(1));
		
		// Association d'un nouveau lieu
		Lieu lieu = new Lieu("Objis","425 cours Emile Zola, 69100 Villeurbanne");
		f.setLieu(lieu);
		
		// Sauvegarde de la formation	
		session.save(f);
	}
	
	protected void tearDown() throws Exception {
		super.tearDown();
		
		// Fermeture transaction
		tx.commit();
		
		// Fermeture unit de travail hibernate
		session.close();
	}
}
